--
-- Cutter
-- This is the specialization for cutters
-- It reacts both to steerable and attachable events
--
-- @author  Stefan Geiger, tune: MySQly
-- @date  04/12/08
--
-- Copyright (C) GIANTS Software GmbH, tune: MySQly , Confidential, All Rights Reserved.

c750 = {};

function c750.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cutter, specializations);
end;
function c750:load(xmlFile)
	self.stol = true;
    self.dual1 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.dual1#index"));
    self.dual2 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.dual2#index"));
	setVisibility(self.dual1, true);



    local rotationPartNodeRight = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartRight#index"));
    if rotationPartNodeRight ~= nil then
        self.rotationPartRight = {};
        self.rotationPartRight.node = rotationPartNodeRight;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartRight#minRot"));
        self.rotationPartRight.minRot = {};
        self.rotationPartRight.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartRight.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartRight.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartRight#maxRot"));
        self.rotationPartRight.maxRot = {};
        self.rotationPartRight.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartRight.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartRight.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartRight.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartRight#rotTime"), 2)*1000;
        self.rotationPartRight.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartRight#touchRotLimit"), 10));
    end;
    self.isReelStarted = SpecializationUtil.callSpecializationsFunction("isReelStarted");
    self.onStartReel = SpecializationUtil.callSpecializationsFunction("onStartReel");
    self.onStopReel = SpecializationUtil.callSpecializationsFunction("onStopReel");
    self.isReelStarted = Cutter.isReelStarted;

    self.reelNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reel#index"));

    self.rollNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.roll#index"));

    local indexSpikesStr = getXMLString(xmlFile, "vehicle.reelspikes#index");
    self.spikesCount = getXMLInt(xmlFile, "vehicle.reelspikes#count");
    self.spikesRootNode = Utils.indexToObject(self.components, indexSpikesStr);

    self.sideArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.sidearms#index"));
    self.sideArmMovable = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.sidearms#movable"), false);

    end;
function c750:delete()
    Utils.deleteParticleSystem(self.threshingParticleSystems);
end;

function c750:mouseEvent(posX, posY, isDown, isUp, button)
end;

function c750:keyEvent(unicode, sym, modifier, isDown)

--[[	if InputBinding.isPressed(InputBinding.Hrauf) then
		self.rotationMaxRight = isDown;
	end;
	if InputBinding.isPressed(InputBinding.Hrunter) then
		self.rotationMinRight = isDown;
	end;

	if InputBinding.isPressed(InputBinding.Rapstisch) then
		self.stol = not self.stol;
		setVisibility(self.dual1, self.stol);
		setVisibility(self.dual2, not self.stol);
	end;

	if InputBinding.isPressed(InputBinding.Hvor) then
		self.translationMax = isDown;
		self.translationMax3 = isDown;
	end;
	if InputBinding.isPressed(InputBinding.Hzurueck) then
		self.translationMin = isDown;
		self.translationMin3 = isDown;
	end;

	if InputBinding.isPressed(InputBinding.Hlangsam) then
		if self.Haspel > 0.001 then
			self.Haspel = self.Haspel - 0.001;
		end;
	end;
	if InputBinding.isPressed(InputBinding.Hschnell) then
		if self.Haspel < 0.005 then
			self.Haspel = self.Haspel + 0.001;
		end;
	end;]]
if isDown and sym == Input.KEY_KP_1 then
		self.helpPanel = not self.helpPanel;
	end;
	if sym == Input.KEY_KP_8 then
		self.rotationMaxRight = isDown;
	end;
	if sym == Input.KEY_KP_2 then
		self.rotationMinRight = isDown;
	end;

	if InputBinding.isPressed(InputBinding.Rapstisch) then
		self.stol = not self.stol;
		setVisibility(self.dual1, self.stol);
		setVisibility(self.dual2, not self.stol);
	end;

	if isDown and sym == Input.KEY_KP_7 then
		if self.reelSpeed > 0.001 then
			self.reelSpeed = self.reelSpeed - 0.0001;
		end;
	end;
	if isDown and sym == Input.KEY_KP_9 then
		if self.reelSpeed < 0.003 then
			self.reelSpeed = self.reelSpeed + 0.0001;
		end;
	end;
end;

function c750:update(dt)

    if self.rotationPartRight ~= nil and (self.rotationMaxRight or self.rotationMinRight) then
        local x, y, z = getRotation(self.rotationPartRight.node);
        local rot = {x,y,z};
        local newRot = Utils.getMovedLimitedValues(rot, self.rotationPartRight.maxRot, self.rotationPartRight.minRot, 3, self.rotationPartRight.rotTime, dt, not self.rotationMaxRight);
        setRotation(self.rotationPartRight.node, unpack(newRot));
    end;


	if self.reelStarted then

        rotate(self.rollNode, -dt*self.reelSpeed*2.5, 0, 0);

        if self.reelNode ~= nil then
            rotate(self.reelNode, -dt*self.reelSpeed*0.001, 0, 0);

            if self.sideArmMovable then
                --:TODO: move arm downwards
            end;

            --correct spikes, so that they always look down
            atx, aty, atz = getRotation(self.reelNode);

            for i=1, self.spikesCount do
                local spike    =    getChildAt(self.spikesRootNode, i-1);
                tx, ty, tz = getRotation(spike);
                setRotation(spike, -atx, aty, atz);
            end;
        end;

	end;


end;
	function c750:draw()

end;

