--
-- physicalCamera
-- Specialization for physically adapting Camera
--
-- @author  Knagsted
-- @date  16/07/10
--

-- Do not edit without my permission
--
physicalCamera = {};

function physicalCamera.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function physicalCamera:load(xmlFile)
	self.cameraRotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.cameraRotNode#index"));

	self.farmerNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.characterNode#index"));

	if self.cameraRotNode ~=nil then
		local x,y,z = getTranslation(self.cameraRotNode);
		self.startXTranslation = x;
		self.startYTranslation = y;
		self.startZTranslation = z;
	end;



	if self.farmerNode ~=nil then
		local x,y,z = getTranslation(self.farmerNode);
		self.startFarmerXTranslation = x;
		self.startFarmerYTranslation = y;
		self.startFarmerZTranslation = z;
	end;




	self.maxTranslationPrCycle = 0.00008;
	self.offsetTranslation = 0;
	self.offsetAdjustmentTranslation = 0;

	if self.wheels[1].repr ~= nil and self.wheels[1].repr ~= nil then
		local x,y,z = getTranslation(self.wheels[1].repr);
		local x2,y2,z2 = getTranslation(self.wheels[2].repr);

		self.averageYTranslation = (y + y2)/2;
	end;

	self.camTranslation = self.averageYTranslation;

end;

function physicalCamera:delete()

end;

function physicalCamera:mouseEvent(posX, posY, isDown, isUp, button)
end;

function physicalCamera:keyEvent(unicode, sym, modifier, isDown)
end;

function physicalCamera:update(dt)
	if self.wheels[1].repr ~= nil and self.wheels[1].repr ~= nil then
		local x,y,z = getTranslation(self.wheels[1].repr);
		local x2,y2,z2 = getTranslation(self.wheels[2].repr);

		self.averageYTranslation = (y + y2)/2;
	end;

	--renderText(0.5, 0.65, 0.040, string.format(self.averageYTranslation));


	if self.camTranslation > self.averageYTranslation then
		self.camTranslation = self.camTranslation - self.maxTranslationPrCycle * dt;
		if self.camTranslation < self.averageYTranslation then
			self.camTranslation = self.averageYTranslation;
		end;
	elseif self.camTranslation < self.averageYTranslation then
		self.camTranslation = self.camTranslation + self.maxTranslationPrCycle * dt;
		if self.camTranslation > self.averageYTranslation then
			self.camTranslation = self.averageYTranslation;
		end;
		--set sound to play if seat damping is very big.

	end;

	--renderText(0.5, 0.75, 0.040, string.format(self.camTranslation));

	if self.cameraRotNode ~= nil then
		setTranslation(self.cameraRotNode, self.startXTranslation, self.camTranslation+self.offsetAdjustmentTranslation, self.startZTranslation);
	end;

	--setup offsetAdjustmentTranslation accoding to weight on tractor
	if self.currentWeight ~= nil then
		self.offsetAdjustmentTranslation = -self.currentWeight * 0.000425;
	else
		self.offsetAdjustmentTranslation = 2.85;
	end;

	self.offsetTranslation = self.camTranslation - self.startYTranslation;

	local adjustedOffsetTranslation = (self.offsetTranslation)+self.offsetAdjustmentTranslation;






end;

function physicalCamera:onLeave()
end;

function physicalCamera:draw()
end;

